.. currentmodule:: obspy.geodetics
.. automodule:: obspy.geodetics

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~base.calc_vincenty_inverse
       ~base.degrees2kilometers
       ~base.gps2dist_azimuth
       ~base.inside_geobounds
       ~base.kilometers2degrees
       ~base.locations2degrees
       ~flinnengdahl.FlinnEngdahl

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       base
       flinnengdahl

    .. comment to end block
